==> openshift-model-machineconfig-6.9.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/CertExpiryFluent.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CertExpiryFluent<A extends CertExpiryFluent<A>> extends BaseFluent<A>{
  public CertExpiryFluent() {
  }
  
  public CertExpiryFluent(CertExpiry instance) {
    this.copyInstance(instance);
  }
  private String bundle;
  private String expiry;
  private String subject;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(CertExpiry instance) {
    instance = (instance != null ? instance : new CertExpiry());
  
    if (instance != null) {
        this.withBundle(instance.getBundle());
        this.withExpiry(instance.getExpiry());
        this.withSubject(instance.getSubject());
        this.withBundle(instance.getBundle());
        this.withExpiry(instance.getExpiry());
        this.withSubject(instance.getSubject());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getBundle() {
    return this.bundle;
  }
  
  public A withBundle(String bundle) {
    this.bundle=bundle; return (A) this;
  }
  
  public boolean hasBundle() {
    return this.bundle != null;
  }
  
  public String getExpiry() {
    return this.expiry;
  }
  
  public A withExpiry(String expiry) {
    this.expiry=expiry; return (A) this;
  }
  
  public boolean hasExpiry() {
    return this.expiry != null;
  }
  
  public String getSubject() {
    return this.subject;
  }
  
  public A withSubject(String subject) {
    this.subject=subject; return (A) this;
  }
  
  public boolean hasSubject() {
    return this.subject != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertExpiryFluent that = (CertExpiryFluent) o;
    if (!java.util.Objects.equals(bundle, that.bundle)) return false;
  
    if (!java.util.Objects.equals(expiry, that.expiry)) return false;
  
    if (!java.util.Objects.equals(subject, that.subject)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(bundle,  expiry,  subject,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bundle != null) { sb.append("bundle:"); sb.append(bundle + ","); }
    if (expiry != null) { sb.append("expiry:"); sb.append(expiry + ","); }
    if (subject != null) { sb.append("subject:"); sb.append(subject + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-machineconfig-6.9.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/CertExpiryFluent.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CertExpiryFluent<A extends CertExpiryFluent<A>> extends BaseFluent<A>{
  public CertExpiryFluent() {
  }
  
  public CertExpiryFluent(CertExpiry instance) {
    this.copyInstance(instance);
  }
  private String bundle;
  private String expiry;
  private String subject;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(CertExpiry instance) {
    instance = (instance != null ? instance : new CertExpiry());
    if (instance != null) {
          this.withBundle(instance.getBundle());
          this.withExpiry(instance.getExpiry());
          this.withSubject(instance.getSubject());
          this.withBundle(instance.getBundle());
          this.withExpiry(instance.getExpiry());
          this.withSubject(instance.getSubject());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getBundle() {
    return this.bundle;
  }
  
  public A withBundle(String bundle) {
    this.bundle = bundle;
    return (A) this;
  }
  
  public boolean hasBundle() {
    return this.bundle != null;
  }
  
  public String getExpiry() {
    return this.expiry;
  }
  
  public A withExpiry(String expiry) {
    this.expiry = expiry;
    return (A) this;
  }
  
  public boolean hasExpiry() {
    return this.expiry != null;
  }
  
  public String getSubject() {
    return this.subject;
  }
  
  public A withSubject(String subject) {
    this.subject = subject;
    return (A) this;
  }
  
  public boolean hasSubject() {
    return this.subject != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertExpiryFluent that = (CertExpiryFluent) o;
    if (!java.util.Objects.equals(bundle, that.bundle)) return false;
    if (!java.util.Objects.equals(expiry, that.expiry)) return false;
    if (!java.util.Objects.equals(subject, that.subject)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(bundle,  expiry,  subject,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bundle != null) { sb.append("bundle:"); sb.append(bundle + ","); }
    if (expiry != null) { sb.append("expiry:"); sb.append(expiry + ","); }
    if (subject != null) { sb.append("subject:"); sb.append(subject + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
